@@ -7,14 +7,14 @@
  * The following global variables are declared by this script:
  *   $ingo_storage - The Ingo_Storage:: object to use for storing rules.
  *
- * $Horde: ingo/lib/base.php,v 1.56.10.2 2006/01/31 20:00:24 jan Exp $
+ * $Horde: ingo/lib/base.php,v 1.56.10.3 2007/12/20 14:05:47 jan Exp $
  *
  * See the enclosed file LICENSE for license information (ASL).  If you
  * did not receive this file, see http://www.horde.org/licenses/asl.php.
  */
 
-// Check for a prior definition of HORDE_BASE (perhaps by an
-// auto_prepend_file definition for site customization).
+// Check for a prior definition of HORDE_BASE (perhaps by an auto_prepend_file
+// definition for site customization).
 if (!defined('HORDE_BASE')) {
     @define('HORDE_BASE', dirname(__FILE__) . '/../..');
 }
@@ -37,8 +37,7 @@ $conf = &$GLOBALS['conf'];
 $notification = &Notification::singleton();
 $notification->attach('status');
 
-// Redirect the user to the Horde login page if they haven't
-// authenticated.
+// Redirect the user to the Horde login page if they haven't authenticated.
 if (!Auth::isAuthenticated() && !defined('AUTH_HANDLER')) {
     Horde::authenticationFailureRedirect();
 }
@@ -58,10 +57,43 @@ Horde::compressOutput();
 // Load the Ingo_Storage driver. It appears in the global variable
 // $ingo_storage.
 require_once INGO_BASE . '/lib/Storage.php';
-$GLOBALS['ingo_storage'] = &Ingo_Storage::singleton();
+$GLOBALS['ingo_storage'] = Ingo_Storage::factory();
 
 // Create the ingo session (if needed).
 if (!isset($_SESSION['ingo']) || !is_array($_SESSION['ingo'])) {
     require_once INGO_BASE . '/lib/Session.php';
     Ingo_Session::createSession();
 }
+
+// Create shares if necessary.
+$driver = Ingo::getDriver();
+if ($driver->supportShares()) {
+    require_once 'Horde/Share.php';
+    $GLOBALS['ingo_shares'] = &Horde_Share::singleton($registry->getApp());
+    $GLOBALS['all_rulesets'] = Ingo::listRulesets();
+
+    /* If personal share doesn't exist then create it. */
+    $signature = $_SESSION['ingo']['backend']['id'] . ':' . Auth::getAuth();
+    if (!$GLOBALS['ingo_shares']->exists($signature)) {
+        require_once 'Horde/Identity.php';
+        $identity = &Identity::singleton();
+        $name = $identity->getValue('fullname');
+        if (trim($name) == '') {
+            $name = Auth::removeHook(Auth::getAuth());
+        }
+        $share = &$GLOBALS['ingo_shares']->newShare($signature);
+        $share->set('name', $name);
+        $GLOBALS['ingo_shares']->addShare($share);
+        $GLOBALS['all_rulesets'][$signature] = &$share;
+    }
+
+    /* Select current share. */
+    $_SESSION['ingo']['current_share'] = Util::getFormData('ruleset', @$_SESSION['ingo']['current_share']);
+    if (empty($_SESSION['ingo']['current_share']) ||
+        empty($GLOBALS['all_rulesets'][$_SESSION['ingo']['current_share']]) ||
+        !$GLOBALS['all_rulesets'][$_SESSION['ingo']['current_share']]->hasPermission(Auth::getAuth(), PERMS_READ)) {
+        $_SESSION['ingo']['current_share'] = $signature;
+    }
+} else {
+    $GLOBALS['ingo_shares'] = null;
+}
