@@ -1,11 +1,13 @@
 <?php
 /**
- * $Horde: ingo/script.php,v 1.33.6.3 2006/01/31 20:00:23 jan Exp $
+ * $Horde: ingo/script.php,v 1.33.6.6 2008/01/02 11:32:08 jan Exp $
  *
- * Copyright 2002-2006 Mike Cochrane <mike@graftonhall.co.nz>
+ * Copyright 2002-2008 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL).  If you
  * did not receive this file, see http://www.horde.org/licenses/asl.php.
+ *
+ * @author Mike Cochrane <mike@graftonhall.co.nz>
  */
 
 @define('INGO_BASE',  dirname(__FILE__));
@@ -20,7 +22,7 @@ if (!$_SESSION['ingo']['script_generate']) {
 $script = '';
 
 /* Get the Ingo_Script:: backend. */
-$scriptor = &Ingo::loadIngoScript();
+$scriptor = Ingo::loadIngoScript();
 if ($scriptor) {
     /* Generate the script. */
     $script = $scriptor->generate();
